.. _api_dimse_messages:

.. py:module:: pynetdicom.dimse_messages

Messages (:mod:`pynetdicom.dimse_messages`)
============================================

.. currentmodule:: pynetdicom.dimse_messages

DIMSE-C Messages
----------------

.. autosummary::
   :toctree: generated/

   C_CANCEL_RQ
   C_ECHO_RQ
   C_ECHO_RSP
   C_FIND_RQ
   C_FIND_RSP
   C_GET_RQ
   C_GET_RSP
   C_MOVE_RQ
   C_MOVE_RSP
   C_STORE_RQ
   C_STORE_RSP


DIMSE-N Messages
----------------

.. autosummary::
   :toctree: generated/

   N_ACTION_RQ
   N_ACTION_RSP
   N_CREATE_RQ
   N_CREATE_RSP
   N_DELETE_RQ
   N_DELETE_RSP
   N_EVENT_REPORT_RQ
   N_EVENT_REPORT_RSP
   N_GET_RQ
   N_GET_RSP
   N_SET_RQ
   N_SET_RSP
